# Generated by Django 4.1.1 on 2022-09-17 18:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("stagedoor", "0004_auto_20200507_2028"),
    ]

    operations = [
        migrations.AlterField(
            model_name="authtoken",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="email",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="phonenumber",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]



# Generated by Django 3.0.5 on 2020-04-08 04:17

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("stagedoor", "0002_auto_20200408_0415"),
    ]

    operations = [
        migrations.AlterField(
            model_name="authtoken",
            name="email",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="stagedoor.Email",
            ),
        ),
        migrations.AlterField(
            model_name="authtoken",
            name="phone_number",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="stagedoor.PhoneNumber",
            ),
        ),
    ]



# Generated by Django 3.0.6 on 2020-05-07 20:28

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("stagedoor", "0003_auto_20200408_0417"),
    ]

    operations = [
        migrations.AddField(
            model_name="email",
            name="potential_user",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="stagedoor_potential_user_email",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
        migrations.AddField(
            model_name="phonenumber",
            name="potential_user",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="stagedoor_potential_user_phone_number",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
    ]
